@@ -1,4 +1,5 @@
 import json
+import os
 
 from django.contrib.gis.db import models
 from django_extensions.db.models import TimeStampedModel
@@ -54,6 +55,10 @@ class SpatialEntry(models.Model):
     def bounds_json(self):
         return json.dumps(self.bounds)
 
+    @property
+    def basename(self):
+        return os.path.basename(self.name)
+
 
 class WhitelistedEmail(models.Model):
     """Pre-approve users for sign up by their email."""
